3.1.3. biosimulators_utils.cellml package — BioSimulators utils 0.1.81 documentation

# 3.1.3. biosimulators_utils.cellml package

## 3.1.3.1. Submodules

## 3.1.3.2. biosimulators_utils.cellml.validation module

Utilities for validating CellML models

Author

  Jonathan Karr <karr@mssm.edu>

Date

  2021-05-10

Copyright

  2021, Center for Reproducible Biomedical Modeling

License

  MIT

biosimulators_utils.cellml.validation.validate_model(filename, name=None)

  Check that a file is a valid CellML 2.0 model

  Parameters

    - filename (`str`) – path to model

    - name (`str`, optional) – name of model for use in error messages

  Returns

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

    - nested `list` of `str`: nested list of errors (e.g., required ids missing or ids not unique)

  Return type

    `tuple`